@@ -2,7 +2,7 @@
 # -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
 #   Catfish - a versatile file searching tool
 #   Copyright (C) 2007-2012 Christian Dywan <christian@twotoasts.de>
-#   Copyright (C) 2012-2014 Sean Davis <smd.seandavis@gmail.com>
+#   Copyright (C) 2012-2015 Sean Davis <smd.seandavis@gmail.com>
 #
 #   This program is free software: you can redistribute it and/or modify it
 #   under the terms of the GNU General Public License version 2, as published
@@ -23,6 +23,7 @@ import io
 import os
 import signal
 import subprocess
+import time
 from itertools import permutations
 
 from mimetypes import guess_type
@@ -30,6 +31,8 @@ from mimetypes import guess_type
 from sys import version_info
 python3 = version_info[0] > 2
 
+engine_count = 0
+
 try:
     from zeitgeist.client import ZeitgeistDBusInterface
     from zeitgeist.datamodel import Event, TimeRange
@@ -66,6 +69,7 @@ def string_regex(keywords, path):
 
 
 class CatfishSearchEngine:
+
     """CatfishSearchEngine is the collection of search backends that are used
     to perform a query.  Each backend is a CatfishSearchMethod"""
 
@@ -78,7 +82,11 @@ class CatfishSearchEngine:
          walk             'os.walk' to search for files (like find).
          zeitgeist        Zeitgeist indexing service to search for files.
         """
-        logger.debug("methods: %s", str(methods))
+        global engine_count
+        engine_count += 1
+        self.engine_id = engine_count
+        logger.debug(
+            "[%i] engine initializing with methods: %s", self.engine_id, str(methods))
         self.methods = []
         if 'zeitgeist' in methods:
             if zeitgeist_support:
@@ -89,6 +97,15 @@ class CatfishSearchEngine:
             self.add_method(CatfishSearchMethod_Fulltext)
         if 'walk' in methods:
             self.add_method(CatfishSearchMethod_Walk)
+        initialized = []
+        for method in self.methods:
+            initialized.append(method.method_name)
+        logger.debug(
+            "[%i] engine initialized with methods: %s", self.engine_id, str(initialized))
+        self.start_time = 0.0
+
+    def __del__(self):
+        logger.debug("[%i] engine destroyed", self.engine_id)
 
     def add_method(self, method_class):
         """Add a CatfishSearchMethod the the engine's search backends."""
@@ -102,10 +119,12 @@ class CatfishSearchEngine:
         This function is a generator.  With each filename reviewed, the
         filename is yielded if it matches the query.  False is also yielded
         afterwards to guarantee the interface does not lock up."""
+        self.start_time = time.time()
+        keywords = keywords.replace(',', ' ').strip().lower()
 
-        logger.debug("path: %s", str(path))
+        logger.debug("[%i] path: %s, keywords: %s, limit: %i, regex: %s",
+                     self.engine_id, str(path), str(keywords), limit, str(regex))
 
-        keywords = keywords.replace(',', ' ')
         self.keywords = keywords
 
         wildcard_chunks = []
@@ -122,15 +141,16 @@ class CatfishSearchEngine:
         # Transform the keywords into a clean list.
         keys = []
         for key in keywords.split():
-            keys.append(key.rstrip().lstrip())
+            keys.append(key.strip())
 
         file_count = 0
         for method in self.methods:
-            logger.debug(method.method_name)
+            logger.debug(
+                "[%i] Starting search method: %s", self.engine_id, method.method_name)
             for filename in method.run(keywords, path, regex):
                 if isinstance(filename, str) and path in filename:
                     if method.method_name == 'fulltext' or  \
-                            all(key.lower() in
+                            all(key in
                                 os.path.basename(filename).lower()
                                 for key in keys):
 
@@ -142,7 +162,7 @@ class CatfishSearchEngine:
                             filename = filename[:filename.index('?')]
 
                         # Remove whitespace from the filename.
-                        filename = filename.rstrip().lstrip()
+                        filename = filename.strip()
 
                         if len(wildcard_chunks) == 0 or \
                                 method.method_name == 'fulltext':
@@ -176,6 +196,7 @@ class CatfishSearchEngine:
                         self.stop()
                         return
                 yield False
+        self.stop()
 
     def set_exact(self, exact):
         """Set method for exact"""
@@ -187,9 +208,13 @@ class CatfishSearchEngine:
         """Stop all running methods."""
         for method in self.methods:
             method.stop()
+        self.stop_time = time.time()
+        clock = self.stop_time - self.start_time
+        logger.debug("[%i] Last query: %f seconds", self.engine_id, clock)
 
 
 class CatfishSearchMethod:
+
     """The base CatfishSearchMethod class, to be inherited by defined
     methods."""
 
@@ -211,6 +236,7 @@ class CatfishSearchMethod:
 
 
 class CatfishSearchMethod_Walk(CatfishSearchMethod):
+
     """Search Method utilizing python 'os.walk'.  This is used as a replacement
     for the 'find' search method, which is difficult to interrupt and is slower
     than os.walk."""
@@ -227,19 +253,15 @@ class CatfishSearchMethod_Walk(CatfishSearchMethod):
         True if still running."""
         self.running = True
         if isinstance(keywords, str):
-            keywords = keywords.replace(',', ' ')
-            keywords = keywords.split()
-        for root, dirs, files in os.walk(path):
+            keywords = keywords.replace(',', ' ').strip().split()
+        for root, dirs, files in os.walk(path, False):
             if not self.running:
                 break
-            for folder in dirs:
-                if any(keyword.lower() in folder.lower()
-                        for keyword in keywords):
-                    yield os.path.join(root, folder)
-            for filename in files:
-                if any(keyword.lower() in filename.lower()
-                        for keyword in keywords):
-                    yield os.path.join(root, filename)
+            paths = dirs + files
+            paths.sort()
+            for path in paths:
+                if any(keyword in path.lower() for keyword in keywords):
+                    yield os.path.join(root, path)
             yield True
         yield False
 
@@ -253,6 +275,7 @@ class CatfishSearchMethod_Walk(CatfishSearchMethod):
 
 
 class CatfishSearchMethod_Fulltext(CatfishSearchMethod):
+
     """Search Method utilizing python 'os.walk' and 'file.readline'.  This is
     used as a replacement for the 'find' search method, which is difficult to
     interrupt and is slower than os.walk."""
@@ -276,12 +299,11 @@ class CatfishSearchMethod_Fulltext(CatfishSearchMethod):
         if not self.exact:
             # Split the keywords into a list if they are not already.
             if isinstance(keywords, str):
-                keywords = keywords.replace(',', ' ')
-                keywords = keywords.split()
+                keywords = keywords.replace(',', ' ').strip().split()
 
             for keyword in keywords:
-                if keyword.lower() not in find_keywords_backup:
-                    find_keywords_backup.append(keyword.lower())
+                if keyword not in find_keywords_backup:
+                    find_keywords_backup.append(keyword)
 
         # Start walking the folder structure.
         for root, dirs, files in os.walk(path):
@@ -311,7 +333,7 @@ class CatfishSearchMethod_Fulltext(CatfishSearchMethod):
                                         yield os.path.join(root, filename)
                                         break
                                 else:
-                                    if any(keyword.lower() in line.lower()
+                                    if any(keyword in line.lower()
                                             for keyword in keywords):
                                         found_keywords = []
                                         for find_keyword in find_keywords:
@@ -345,8 +367,10 @@ class CatfishSearchMethod_Fulltext(CatfishSearchMethod):
 
 
 class CatfishSearchMethod_Zeitgeist(CatfishSearchMethod):
+
     """Search Method utilziing python's Zeitgeist integration.  This is used
     to provide the fastest results, usually benefitting search suggestions."""
+
     def __init__(self):
         """Initialize the Zeitgeist SearchMethod."""
         CatfishSearchMethod.__init__(self, "zeitgeist")
@@ -394,6 +418,7 @@ class CatfishSearchMethod_Zeitgeist(CatfishSearchMethod):
 
 
 class CatfishSearchMethodExternal(CatfishSearchMethod):
+
     """The base CatfishSearchMethodExternal class, which is used for getting
     results from shell queries."""
 
@@ -419,7 +444,7 @@ class CatfishSearchMethodExternal(CatfishSearchMethod):
         if regex:
             command = self.assemble_query(keywords, path)
         if not command:
-            command = [item.replace('%keywords', keywords.lower())
+            command = [item.replace('%keywords', keywords)
                        for item in self.command]
         command = [item.replace('%path', path) for item in command]
         self.process = subprocess.Popen(command, stdout=subprocess.PIPE,
@@ -459,7 +484,9 @@ class CatfishSearchMethodExternal(CatfishSearchMethod):
 
 
 class CatfishSearchMethod_Locate(CatfishSearchMethodExternal):
+
     """External Search Method utilizing the system command 'locate'."""
+
     def __init__(self):
         """Initialize the Locate SearchMethod."""
         CatfishSearchMethodExternal.__init__(self, "locate")
