@@ -2,7 +2,7 @@
 # -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
 #   Catfish - a versatile file searching tool
 #   Copyright (C) 2007-2012 Christian Dywan <christian@twotoasts.de>
-#   Copyright (C) 2012-2014 Sean Davis <smd.seandavis@gmail.com>
+#   Copyright (C) 2012-2015 Sean Davis <smd.seandavis@gmail.com>
 #
 #   This program is free software: you can redistribute it and/or modify it
 #   under the terms of the GNU General Public License version 2, as published
@@ -20,18 +20,22 @@ __all__ = [
     'project_path_not_found',
     'get_data_file',
     'get_data_path',
+    'get_locate_db_path',
 ]
 
 # Where your project will look for your data (for instance, images and ui
 # files). By default, this is ../data, relative your trunk layout
 __catfish_data_directory__ = '../data/'
+# Location of locate.db file
+__locate_db_path__ = '/var/lib/mlocate/mlocate.db'
 __license__ = 'GPL-2'
-__version__ = '1.2.2'
+__version__ = '1.3.0'
 
 import os
 
 
 class project_path_not_found(Exception):
+
     """Raised when we can't find the project directory."""
 
 
@@ -64,6 +68,12 @@ def get_data_path():
     return abs_data_path
 
 
+def get_locate_db_path():
+    """Return the location of the locate.db file
+    """
+    return __locate_db_path__
+
+
 def get_version():
     """Return the program version number."""
     return __version__
